@@ -738,10 +738,15 @@ def pretraining_numpy(arr, batch_size, shuffle=False, max_obs=100,
 
 def pretraining_data(data, batch_size, shuffle=False, max_obs=100,
                         msk_frac=0.2, rnd_frac=0.1, same_frac=0.1, mode=None):
+    modes = ["clf"]
+    if mode not in modes:
+        raise ValueError(f"Mode {mode} is not defined. Please select among {modes}")
+    
     if isinstance(data, list):
         data =  pretraining_numpy(data, batch_size, shuffle=shuffle, max_obs=max_obs,
                         msk_frac=msk_frac, rnd_frac=rnd_frac, same_frac=same_frac)
         return data
+
     elif isinstance(data, str):
         if mode=="clf":
             data =  pretraining_records_v2(data, batch_size, shuffle=shuffle, max_obs=max_obs,
